@@ -27,9 +27,9 @@
  *
  * Contributor(s): /
  *
- * $Revision: 23182 $
+ * $Revision: 26416 $
  * $Author: rjongbloed $
- * $Date: 2009-07-29 04:43:11 -0500 (Wed, 29 Jul 2009) $
+ * $Date: 2011-09-12 20:28:32 -0500 (Mon, 12 Sep 2011) $
  */
 
 #pragma implementation "sound_alsa.h"
@@ -67,14 +67,14 @@ PSoundChannelALSA::PSoundChannelALSA(const PString & device,
 
 void PSoundChannelALSA::Construct()
 {
-  enum _snd_pcm_format val;
-
-#if PBYTE_ORDER == PLITTLE_ENDIAN
-  val = (mBitsPerSample == 16) ? SND_PCM_FORMAT_S16_LE : SND_PCM_FORMAT_U8;
-#else
-  val = (mBitsPerSample == 16) ? SND_PCM_FORMAT_S16_BE : SND_PCM_FORMAT_U8;
-#endif
-
+//  enum _snd_pcm_format val;
+//
+//#if PBYTE_ORDER == PLITTLE_ENDIAN
+//  val = (mBitsPerSample == 16) ? SND_PCM_FORMAT_S16_LE : SND_PCM_FORMAT_U8;
+//#else
+//  val = (mBitsPerSample == 16) ? SND_PCM_FORMAT_S16_BE : SND_PCM_FORMAT_U8;
+//#endif
+//
   frameBytes = 2;
   m_bufferSize = 320; // 20 ms worth of 8kHz data
   m_bufferCount = 2;  // double buffering
@@ -403,21 +403,25 @@ PBoolean PSoundChannelALSA::Write(const void *buf, PINDEX len)
       lastWriteCount += r * frameBytes;
     }
     else {
+      PTRACE(5, "ALSA\tBuffer underrun detected. Recovering... ");
       if (r == -EPIPE) {    /* under-run */
         r = snd_pcm_prepare(os_handle);
-        if (r < 0) {
-          PTRACE(1, "ALSA\tCould not prepare device: " << snd_strerror(r));
-        }
+        PTRACE_IF(1, r < 0, "ALSA\tCould not prepare device: " << snd_strerror(r));
       }
       else if (r == -ESTRPIPE) {
+        PTRACE(5, "ALSA\tOutput suspended. Resuming... ");
         while ((r = snd_pcm_resume(os_handle)) == -EAGAIN)
           sleep(1);       /* wait until the suspend flag is released */
 
-        if (r < 0)
-          snd_pcm_prepare(os_handle);
+        if (r < 0) {
+          r = snd_pcm_prepare(os_handle);
+          PTRACE_IF(1, r < 0, "ALSA\tCould not prepare device: " << snd_strerror(r));
+        }
+      }
+      else {
+        PTRACE(1, "ALSA\tCould not write " << max_try << " " << len << " " << snd_strerror(r));
       }
 
-      PTRACE(1, "ALSA\tCould not write " << max_try << " " << len << " " << snd_strerror(r));
       max_try++;
       if (max_try > 5)
         return false;
